@@ -185,7 +185,7 @@ class Filter:
         """
         Prepare a filter object from a list of filters, or from a condition object
         :param filters: The filters
-        :param convert_ints: Whether to convert anything that can be converted to int, to an int
+        :param convert_ints: Whether to convert digit-only strings to integers or not
         :param empty_filters_response: What is returned if there are no filters. Makes the difference between
             returning all items for empty filters, or returning none.
         :param missing_field_response: What is returned for a filter if the field was not present.
@@ -250,12 +250,19 @@ class Filter:
 
         return self.empty_filters_response if overall is None else overall
 
-    def single(self, item: Union[dict, list]) -> bool:
+    def single(self, item) -> bool:
+        """
+        Filter a single item
+        :param item: The item to filter
+        :return: Whether or not the item meets the filter
+        """
         return self._filter(item)
 
-    def many(self, items: List[Union[dict, list]]) -> List[Union[dict, list]]:
+    def many(self, items: List[any]) -> List[any]:
         """
-        Take a list of items and only return the ones that meet the filter conditions
+        Filter the list of items
+        :param items: The items to filter
+        :return: Only the items that satisfy the filter
         """
         return [
             item for item in items if self._filter(item)
