@@ -126,7 +126,7 @@ class Query:
         Create a query object from a JQL query string, or list of JQL query strings.
         :param query: The JQL query string(s)
         :param convert_ints: Whether to treat digit-only field values as integers or strings
-        :param fallback: A fallback value that will be used if field cannot be found for a given object
+        :param fallback: A fallback value that will be used if a field cannot be found
         """
         self.multiple: bool = not (isinstance(query, str) or isinstance(query, JQLQuery))
         self.fields: Union[List[str], List[JQLQuery]] = query if self.multiple else [query]
@@ -206,7 +206,7 @@ class Query:
         """
         Query the items
         :param items: The items to query
-        :return: A list of values, or a list of list of values, depending on whether one or multiple queries are present
+        :return: A list of values or a list of lists of values, depending on whether one or multiple queries are present
         """
         return [self.single(item) for item in items]
 
@@ -217,6 +217,7 @@ class Query:
         The function should take at least one argument, which will be the current value in query.
         :param name: The name of the special - must only contain these characters: [-a-zA-Z0-9_]
         :param func: The function that will be applied to the value
+        :return Whether or not the special could be registered
         """
         if name not in cls._specials:
             cls._specials[name] = func
